BrainCloudFile class

Constructors

BrainCloudFile(BrainCloudClient _clientRef)

Properties

fileStorage Map<String, Uint8List>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancelUpload({required String uploadId}) → void
Method cancels an upload. If an IFileUploadCallback has been registered with the BrainCloudClient class, the fileUploadFailed callback method will be called once the upload has been canceled.
deleteUserFile({required String cloudPath, required String cloudFilename}) Future<ServerResponse>
Deletes a single user file.
deleteUserFiles({required String cloudPath, required bool recurse}) Future<ServerResponse>
Delete multiple user files
getCDNUrl({required String cloudPath, required String cloudFilename}) Future<ServerResponse>
Returns the CDN URL for a file dynamic.
getUploadBytesTransferred({required String uploadId}) int?
Returns the number of bytes uploaded or -1 if upload not found.
getUploadProgress({required String uploadId}) double?
Returns the progress of the given upload from 0.0 to 1.0 or -1 if upload not found.
getUploadTotalBytesToTransfer({required String uploadId}) int?
Returns the total number of bytes that will be uploaded or -1 if upload not found. @param uploadIdThe id of the upload
listUserFiles({required String cloudPath, bool? recurse}) Future<ServerResponse>
List user files from the given cloud path
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
uploadFileFromMemory({required String cloudPath, required String cloudFilename, required bool shareable, required bool replaceIfExists, required Uint8List fileData}) Future<ServerResponse>
Prepares a user file upload from memory, allowing the user to bypass the need to read or write on disk before uploading. On success the file will begin uploading to the brainCloud server.To be informed of success/failure of the upload register an IFileUploadCallback with the BrainCloudClient class.

Operators

operator ==(Object other) bool
The equality operator.
inherited