BrainCloudMessaging class

Constructors

BrainCloudMessaging(BrainCloudClient _clientRef)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

deleteMessages({required String msgBox, required List<String> msgsIds}) Future<ServerResponse>
Deletes specified user messages on the server. in_msgBox = OperationParam.inboxMessageType && OperationParam.sentMessageType
getMessageBoxes() Future<ServerResponse>
Retrieve user's message boxes, including 'inbox', 'sent', etc.
getMessageCounts() Future<ServerResponse>
Returns count of user's 'total' messages and their 'unread' messages.
getMessages({required String msgBox, required List<String> msgIds, required bool markAsRead}) Future<ServerResponse>
Retrieves list of specified messages.
getMessagesPage({required Map<String, dynamic> context}) Future<ServerResponse>
Retrieves a page of messages.
getMessagesPageOffset({required String context, required int pageOffset}) Future<ServerResponse>
Gets the page of messages from the server based on the encoded context and specified page offset.
markMessagesRead({required String msgBox, required List<String> msgsIds}) Future<ServerResponse>
Marks list of user messages as read on the server.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendMessage({required List<String> toProfileIds, required Map<String, dynamic> contentJson}) Future<ServerResponse>
Sends a message with specified 'subject' and 'text' to list of users.
sendMessageSimple({required List<String> toProfileIds, required String text}) Future<ServerResponse>
Send a potentially rich chat message. content must contain at least a "plain" field for plain-text messaging.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited