BrainCloudTournament class

Constructors

BrainCloudTournament(BrainCloudClient _clientRef)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

claimTournamentReward({required String leaderboardId, required int versionId}) Future<ServerResponse>
Processes any outstanding rewards for the given player
getDivisionInfo({required String divSetId}) Future<ServerResponse>
Gets the info of specified division set
getMyDivisions() Future<ServerResponse>
Gets the player's recently active divisions
getTournamentStatus({required String leaderboardId, required int versionId}) Future<ServerResponse>
Get tournament status associated with a leaderboard
joinDivision({required String divSetId, required String tournamentCode, required int initialScore}) Future<ServerResponse>
Gets the info of specified division set
joinTournament({required String leaderboardId, required String tournamentCode, required int initialScore}) Future<ServerResponse>
Join the specified tournament. Any entry fees will be automatically collected.
leaveDivisionInstance({required String divisionSetInstance}) Future<ServerResponse>
Gets the info of specified division set
leaveTournament({required String leaderboardId}) Future<ServerResponse>
Removes player's score from tournament leaderboard
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
postTournamentScoreUTC({required String leaderboardId, required int score, Map<String, dynamic>? data, required int roundStartTimeUTC}) Future<ServerResponse>
Post the users score to the leaderboard
postTournamentScoreWithResultsUTC({required String leaderboardId, required int score, Map<String, dynamic>? data, required int roundStartTimeUTC, required SortOrder sort, required int beforeCount, required int afterCount, required int initialScore}) Future<ServerResponse>
Post the users score to the leaderboard and returns the results
toString() String
A string representation of this object.
inherited
viewCurrentReward({required String leaderboardId}) Future<ServerResponse>
Returns the user's expected reward based on the current scores
viewReward({required String leaderboardId, required int versionId}) Future<ServerResponse>
Returns the user's reward from a finished tournament

Operators

operator ==(Object other) bool
The equality operator.
inherited