Method cancels an upload. If an IFileUploadCallback has been registered with the BrainCloudClient class,
the fileUploadFailed callback method will be called once the upload has been canceled.
Prepares a user file upload from memory, allowing the user to bypass
the need to read or write on disk before uploading. On success the file will begin uploading
to the brainCloud server.To be informed of success/failure of the upload
register an IFileUploadCallback with the BrainCloudClient class.